==> haskell-hls-eval-plugin-2.0.0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-eval-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-eval-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-eval-plugin-2.0.0.0-BoHAt5XPOhHLJYVQBCoZvC
key:                  hls-eval-plugin-2.0.0.0-BoHAt5XPOhHLJYVQBCoZvC
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  bd91ee889171ee41a20a176a98a19f74
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.0.0.0-BoHAt5XPOhHLJYVQBCoZvC
depends:
    Diff-0.4.1-LH1ky1AbixJl32mO74dkD
    QuickCheck-2.14.3-6d1PIKLXLdiAlrbWNDjj9l
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghcide-2.0.0.0-AWKPNAHSA153zaZtgTpP3V
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hls-graph-2.0.0.0-60x3ybMrD4x7nBwBcJteyH
    hls-plugin-api-2.0.0.0-8UXQK9xyJ6Qq1nXPMTcOV
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1 lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv
    lsp-types-1.6.0.1-KcckgHP1cSAQeTZDkGSeD
    megaparsec-9.6.1-2HDqovyWdJD7TkiDY5U33O mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    pretty-simple-4.1.3.0-Hej2b0TxAMTLpMjeRpupzQ
    safe-exceptions-0.1.7.4-ES7S1HwS0lOI4lBBxEPT7M text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-LfkN9oBuVsC1PSAv8s4AS5
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-eval-plugin-2.0.0.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-eval-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-eval-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-eval-plugin-2.0.0.0-G57g3JMgqCaAItSvItQnIA
key:                  hls-eval-plugin-2.0.0.0-G57g3JMgqCaAItSvItQnIA
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:             Eval plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  3647ae89ede1d3d4fd556a65734c481b
exposed:              True
exposed-modules:      Ide.Plugin.Eval Ide.Plugin.Eval.Types
hidden-modules:
    Ide.Plugin.Eval.Code Ide.Plugin.Eval.CodeLens
    Ide.Plugin.Eval.Config Ide.Plugin.Eval.GHC
    Ide.Plugin.Eval.Parse.Comments Ide.Plugin.Eval.Parse.Option
    Ide.Plugin.Eval.Rules Ide.Plugin.Eval.Util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-eval-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-eval-plugin
hs-libraries:         HShls-eval-plugin-2.0.0.0-G57g3JMgqCaAItSvItQnIA
depends:
    Diff-0.4.1-LH1ky1AbixJl32mO74dkD
    QuickCheck-2.14.3-6d1PIKLXLdiAlrbWNDjj9l
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK filepath-1.4.2.2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghcide-2.0.0.0-DRI4NY9c6PIkGk9WaJTQj
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hls-graph-2.0.0.0-60x3ybMrD4x7nBwBcJteyH
    hls-plugin-api-2.0.0.0-I7YEHyKncWN58S7zoavJND
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1 lsp-1.6.0.0-LOrWurGUfcm1ZXl1RcyPxv
    lsp-types-1.6.0.1-KcckgHP1cSAQeTZDkGSeD
    megaparsec-9.6.1-2HDqovyWdJD7TkiDY5U33O mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    pretty-simple-4.1.3.0-Hej2b0TxAMTLpMjeRpupzQ
    safe-exceptions-0.1.7.4-ES7S1HwS0lOI4lBBxEPT7M text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-LfkN9oBuVsC1PSAv8s4AS5
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-eval-plugin/html/hls-eval-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-eval-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
